@@ -39,23 +39,23 @@ def paramodulation(
     r"""
     binary paramodulation rule
 
-    .. math:: {\frac{\Gamma_1\cup\left\{s\approx t\right\},\Gamma_2\cup \left\{L\left[r\right]\right\}}{\left(\left\{L\left[t\right]\right\}\cup\Gamma_1\cup\Gamma_2\right)\phi}}
+    .. math:: {\frac{C_1\vee s\approx t,C_2\vee L\left[r\right]}{\sigma\left(L\left[t\right]\vee C_1\vee C_2\right)}}
 
     where
 
-    * :math:`\Gamma_1` and :math:`\Gamma_2` are clauses with no common variables
-    * :math:`L\left[r\right]` is a literal with subterm :math:`r`
+    * :math:`C_1` and :math:`C_2` are clauses with no common variables
+    * :math:`L\left[r\right]` is a literal with a subterm :math:`r`
     * only one instance of :math:`r` in :math:`L\left[r\right]` is considered, even if there are many of them
     * :math:`s` and :math:`t` are terms, :math:`\approx` is a syntactic equality symbol
-    * :math:`\phi` is a most general unifier of :math:`s` and :math:`r`
+    * :math:`\sigma` is a most general unifier of :math:`s` and :math:`r`
 
     >>> from gym_saturation.grammar import Predicate, Variable, Function
     >>> paramodulation(Clause([Literal(False, Predicate("q", [Variable("X")]))]), [Variable("X"), Function("this_is_a_test_case", [])], Clause([Literal(False, Predicate("r", [Variable("X")]))]), Literal(True, Predicate("p", [Function("f", [])])), 1).literals
     [Literal(negated=True, atom=Predicate(name='p', arguments=[Function(name='this_is_a_test_case', arguments=[])])), Literal(negated=False, atom=Predicate(name='q', arguments=[Function(name='f', arguments=[])])), Literal(negated=False, atom=Predicate(name='r', arguments=[Function(name='f', arguments=[])]))]
 
-    :param clause_one: :math:`\Gamma_1`
+    :param clause_one: :math:`C_1`
     :param literal_one: :math:`s\approx t`
-    :param clause_two: :math:`\Gamma_2`
+    :param clause_two: :math:`C_2`
     :param literal_two: :math:`L\left[r\right]`
     :param r_position: index of :math:`r` in the tree of subterms of :math:`L\left[r\right]`
     :returns: a new clause --- the paramodulation result
@@ -86,7 +86,7 @@ def paramodulation(
 def _equality_symmetry_paramodulation(
     clause_one, literal_one, clause_two, literal_two, k
 ):
-    paramodulants = list()
+    paramodulants = []
     try:
         paramodulants.append(
             paramodulation(
@@ -130,9 +130,9 @@ def all_paramodulants_from_clause(
     applies ``paramodulation`` with varying ``r_position`` argument
     also varies for equality symmetry
 
-    :param clause_one: :math:`\Gamma_1`
+    :param clause_one: :math:`C_1`
     :param literal_one: :math:`s\approx t`
-    :param clause_two: :math:`\Gamma_2`
+    :param clause_two: :math:`C_2`
     :param literal_two: :math:`L\left[r\right]`
     :returns: a list of paramodulants for all possible values of ``r_position``
     """
@@ -145,7 +145,7 @@ def all_paramodulants_from_clause(
     if literal_one.atom.arguments[0] == literal_one.atom.arguments[1]:
         return []
     literal_two_len = proposition_length(literal_two.atom)
-    paramodulants = list()
+    paramodulants = []
     for k in range(1, literal_two_len):
         paramodulants.extend(
             _equality_symmetry_paramodulation(
@@ -158,7 +158,7 @@ def all_paramodulants_from_clause(
 def _get_new_paramodulants(
     clause_one: Clause, literal_one: Literal, given_clause: Clause
 ) -> List[Clause]:
-    paramodulants = list()
+    paramodulants = []
     for j, literal_two in enumerate(given_clause.literals):
         clause_two = Clause(
             given_clause.literals[:j] + given_clause.literals[j + 1 :]
@@ -216,7 +216,7 @@ def all_paramodulants_from_list(
     """
     if given_clause.label is None:
         raise ValueError(f"no label: {given_clause}")
-    paramodulants: List[Clause] = list()
+    paramodulants: List[Clause] = []
     for other_clause in clauses:
         for i, literal_one in enumerate(other_clause.literals):
             clause_one = Clause(
