@@ -13,6 +13,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+from itertools import chain
 from typing import List, Union
 
 from gym_saturation.grammar import (
@@ -55,7 +56,7 @@ def get_variable_list(clause: Union[Clause, Proposition]) -> List[Variable]:
     :param clause: a clause
     :returns: a list (with repetitions) of variables from there clause
     """
-    variable_list = list()
+    variable_list = []
     if isinstance(clause, Clause):
         for literal in clause.literals:
             for term in literal.atom.arguments:
@@ -78,7 +79,7 @@ def reindex_variables(clauses: List[Clause], prefix: str) -> List[Clause]:
     :returns: the list of clauses with renamed variables
     """
     variable_count = 0
-    new_clauses = list()
+    new_clauses = []
     for clause in clauses:
         new_clause = clause
         variable_list = deduplicate(get_variable_list(clause))
@@ -273,3 +274,47 @@ def replace_subterm_by_index(
             except NoSubtermFound as error:
                 subterm_length += error.args[0]
     raise NoSubtermFound(subterm_length)
+
+
+def reduce_to_proof(clauses: List[Clause]) -> List[Clause]:
+    """
+    leave only clauses belonging to the refutational proof
+
+    >>> reduce_to_proof([Clause([])])
+    Traceback (most recent call last):
+     ...
+    ValueError: wrong refutation proof
+    >>> state = [Clause([], label="one", processed=True)]
+    >>> reduce_to_proof(state) == state
+    True
+
+    :param clauses: a list of clauses with labels and inference records
+    :returns: the reduced list of clauses
+    """
+    state_dict = {clause.label: clause for clause in clauses}
+    empty_clauses = [
+        clause
+        for label, clause in state_dict.items()
+        if clause.literals == [] and clause.processed
+    ]
+    if len(empty_clauses) == 1:
+        if empty_clauses[0].label is not None:
+            reduced = []
+            new_reduced = [empty_clauses[0]]
+            while len(new_reduced) > 0:
+                reduced += new_reduced
+                new_reduced = [
+                    state_dict[label]
+                    for label in chain(
+                        *[
+                            (
+                                []
+                                if clause.inference_parents is None
+                                else clause.inference_parents
+                            )
+                            for clause in new_reduced
+                        ]
+                    )
+                ]
+            return reduced
+    raise ValueError("wrong refutation proof")
